//@line 36 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/locales/../../mail/locales/en-US/all-l10n.js"

//@line 38 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/locales/../../mail/locales/en-US/all-l10n.js"

pref("general.useragent.locale", "en-US");
